@@ -1,15 +1,10 @@
 package Password::Policy::Encryption::Plaintext;
-{
-  $Password::Policy::Encryption::Plaintext::VERSION = '0.02';
-}
-
+$Password::Policy::Encryption::Plaintext::VERSION = '0.03';
 use strict;
 use warnings;
 
 use parent 'Password::Policy::Encryption';
 
-use String::Multibyte;
-
 sub enc {
     my $self = shift;
     my $password = $self->prepare(shift);
@@ -18,17 +13,19 @@ sub enc {
 
 1;
 
-
+__END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Password::Policy::Encryption::Plaintext
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 AUTHOR
 
@@ -42,8 +39,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
-
