@@ -1,15 +1,10 @@
 package Password::Policy::Rule::Whitespace;
-{
-  $Password::Policy::Rule::Whitespace::VERSION = '0.02';
-}
-
+$Password::Policy::Rule::Whitespace::VERSION = '0.03';
 use strict;
 use warnings;
 
 use parent 'Password::Policy::Rule';
 
-use String::Multibyte;
-
 use Password::Policy::Exception::InsufficientWhitespace;
 
 sub check {
@@ -25,17 +20,19 @@ sub check {
 
 1;
 
-
+__END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Password::Policy::Rule::Whitespace
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 AUTHOR
 
@@ -49,6 +46,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
